@@ -1,10 +1,15 @@
+from loguru import logger
+
+
 class Validator:
     def __init__(self, data):
         self.instance = data["class"]
         self.data = data["data"]
-        self.dataset = data["dataset"]
+        if "dataset" in data:
+            self.dataset = data["dataset"]
 
     def receita_federal_validator(self):
+        logger.info("Running Receita Federal validator")
         if "emails_extended" in self.dataset:
             if not self.data["mail"]:
                 return False
