@@ -63,6 +63,13 @@ class ReceitaFederalPJData(BaseData):
     is_headquarter: Optional[bool] = None
     main_activity: Optional[str] = None
     activities: Optional[List[str]] = None
+    address: Optional[str] = None
+    city: Optional[str] = None
+    neighborhood: Optional[str] = None
+    state: Optional[str] = None
+    zip_code: Optional[str] = None
+    mail: Optional[str] = None
+    phone: Optional[str] = None
 
 
 class ReceitaFederalPJSerializer(BaseSchema):
@@ -77,6 +84,13 @@ class ReceitaFederalPJSerializer(BaseSchema):
     activities = fields.List(fields.String, allow_none=True)
     main_activity = fields.String(allow_none=True)
     payload = fields.Dict(allow_none=True)
+    address = fields.String(allow_none=True)
+    city = fields.String(allow_none=True)
+    neighborhood = fields.String(allow_none=True)
+    state = fields.String(allow_none=True)
+    zip_code = fields.String(allow_none=True)
+    mail = fields.String(allow_none=True)
+    phone = fields.String(allow_none=True)
 
     @pre_load
     def log_received_data(self, data, **kwargs) -> Dict[Any, Any]:
